﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Diagnostics;

namespace WamGrid_Select_2Events
{
    public class ViewModel : INotifyPropertyChanged
    {
        #region PropertyChanged
        public event PropertyChangedEventHandler PropertyChanged;

        private void NotifyPropertyChanged(String info)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(info));
            }
        }
        #endregion

        private ObservableCollection<T_Person> _elements;
        public ObservableCollection<T_Person> Elements
        {
            get { return _elements; }
            set { 
                _elements = value;
                this.NotifyPropertyChanged("Elements");
            }
        }

        private T_Person _oneElement;
        public T_Person OneElement
        {
            get { return _oneElement; }
            set {
                _oneElement = value;
                this.NotifyPropertyChanged("OneElement");

                if (value != null)
                {
                    this.LoadData();
                }
            
            }
        }

        private bool _isEnabled;
        public bool IsEnabled
        {
            get { return _isEnabled; }
            set
            {
                _isEnabled = value;
                this.NotifyPropertyChanged("IsEnabled");
            }
        }

        /// <summary>
        /// Loading data from database : can take som time....
        /// </summary>
        public void LoadData()
        {
            // When IsEnabled is set to true, focus is set to the text field
            // Same thing happen when BusyIndicator is used in LoadData() :
            //          1 - focus is set somewhere inside BusyIndicator (by BusyIndicator itself)
            //          2 - edit button is loosing focus and "click" event is never raised
            
            Debug.WriteLine("--- LoadData() : Start loading data - can take a while");

            // Put IsEnabled to true only for last element
            if (this.OneElement == this.Elements[2])
            {
                this.IsEnabled = true;
            }
            else
            {
                this.IsEnabled = false;
            }

            Debug.WriteLine("--- LoadData() : End loading data");
        }
 
    }
}
